@@ -369,7 +369,7 @@ sub auto_index_in_process {
     return unless -e $flag_file;
 
     # if flagfile exists, then check that PID still exists
-    open my $fh,$flag_file or die "Couldn't open $flag_file: $!";
+    open my $fh, '<', $flag_file or $self->throw("Could not read file '$flag_file': $!");
     my $pid = <$fh>;
     close $fh;
     return 1 if kill 0=>$pid;
@@ -393,7 +393,7 @@ sub flag_autoindexing {
     my $doit = shift;
     my $flag_file = $self->autoindex_flagfile;
     if ($doit) {
-	open my $fh,'>',$flag_file or die "Couldn't open $flag_file: $!";
+	open my $fh, '>', $flag_file or $self->throw("Could not write file '$flag_file': $!");
 	print $fh $$;
 	close $fh;
     } else {
@@ -621,6 +621,7 @@ sub _open_databases {
     return if $ignore_errors;  # autoindex set, so defer this
     $self->throw("Couldn't tie: ".$self->_features_path . " $!");
   }
+
   if ($create) {
     %h = ();
     $h{'.next_id'} = 1;
@@ -672,7 +673,8 @@ sub open_notes_db {
 	                : $create ? "+>"
 	                : "<";
 
-    open (my $F,$mode,$self->_notes_path) or $self->throw($self->_notes_path.": $!");
+    my $notes_file = $self->_notes_path;
+    open my $F, $mode, $notes_file or $self->throw("Could not open file '$notes_file': $!");
     $self->notes_db($F);
 }
 
@@ -701,6 +703,7 @@ sub _close_databases {
   $self->db(undef);
   $self->dna_db(undef);
   $self->notes_db(undef);
+  $self->parentage_db(undef);
   $self->index_db($_=>undef) foreach $self->_index_files;
 }
 
@@ -722,9 +725,9 @@ sub _delete_databases {
 sub _touch_timestamp {
   my $self = shift;
   my $tsf = $self->_mtime_path;
-  open (F,">$tsf") or $self->throw("Couldn't open $tsf: $!");
-  print F scalar(localtime);
-  close F;
+  open my $F, '>', $tsf or $self->throw("Could not write file '$tsf': $!");
+  print $F scalar(localtime);
+  close $F;
 }
 
 sub _store {
@@ -1449,6 +1452,7 @@ sub db_version {
 sub DESTROY {
   my $self = shift;
   $self->_close_databases();
+  $self->private_fasta_file->close;
   rmtree($self->directory,0,1) if $self->temporary && -e $self->directory;
 }
 
@@ -1575,4 +1579,3 @@ This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
 
 =cut
-
