@@ -108,7 +108,7 @@ Report bugs to the Bioperl bug tracking system to help us keep track
 the bugs and their resolution.  Bug reports can be submitted via the
 web:
 
-  https://redmine.open-bio.org/projects/bioperl/
+  https://github.com/bioperl/bioperl-live/issues
 
 =head1 AUTHOR - Ewan Birney
 
@@ -232,13 +232,15 @@ sub new {
         }
     }
 
-    $desc         && $self->desc($desc);
-    $description  && $self->description($description);
-    $is_circular  && $self->is_circular($is_circular);
-    $ns           && $self->namespace($ns);
-    $auth         && $self->authority($auth);
-    defined($v)   && $self->version($v);
-    defined($oid) && $self->object_id($oid);
+    $desc                  && $self->desc($desc);
+    $description           && $self->description($description);
+    $ns                    && $self->namespace($ns);
+    $auth                  && $self->authority($auth);
+    # Any variable that can have a value "0" must be tested with defined
+    # or it will fail to be added to the new object
+    defined($v)            && $self->version($v);
+    defined($oid)          && $self->object_id($oid);
+    defined($is_circular)  && $self->is_circular($is_circular);
 
     return $self;
 }
@@ -383,13 +385,31 @@ sub subseq {
     if( ref($start) && $start->isa('Bio::LocationI') ) {
         my $loc = $start;
         my $seq = '';
-        foreach my $subloc ($loc->each_Location()) {
+
+        # For Split objects if Guide Strand is negative,
+        # pass the sublocations in reverse
+        my $order = 0;
+        if ($loc->isa('Bio::Location::SplitLocationI')) {
+            # guide_strand can return undef, so don't compare directly
+            # to avoid 'uninitialized value' warning
+            my $guide_strand = defined ($loc->guide_strand) ? ($loc->guide_strand) : 0;
+            $order = ($guide_strand == -1) ? -1 : 0;
+        }
+        # Reversing order using ->each_Location(-1) does not work well for
+        # cut by origin-splits (like "complement(join(1900..END,START..50))"),
+        # so use "reverse" instead
+        my @sublocs = ($order == -1) ? reverse $loc->each_Location(): $loc->each_Location;
+        foreach my $subloc (@sublocs) {
             my $piece = $self->subseq(-start        => $subloc->start(),
                                       -end          => $subloc->end(),
                                       -replace_with => $replace,
                                       -nogap        => $nogap);
             $piece =~ s/[$GAP_SYMBOLS]//g if $nogap;
-            if ($subloc->strand() < 0) {
+
+            # strand can return undef, so don't compare directly
+            # to avoid 'uninitialized value' warning
+            my $strand = defined ($subloc->strand) ? ($subloc->strand) : 0;
+            if ($strand < 0) {
                 $piece = $self->_revcom_from_string($piece, $self->alphabet);
             }
             $seq .= $piece;
@@ -450,13 +470,12 @@ sub subseq {
  Title   : length
  Usage   : $len = $seqobj->length();
  Function: Get the stored length of the sequence in number of symbols (bases
-           or amino acids).
+           or amino acids). In some circumstances, you can also set this attribute:
 
-           In some circumstances, you can also set this attribute:
-           1/ For empty sequences, you can set the length to anything you want:
+           1. For empty sequences, you can set the length to anything you want:
               my $seqobj = Bio::PrimarySeq->new( -length => 123 );
               my $len = $seqobj->len; # 123
-           2/ To save memory when using very long sequences, you can set the
+           2. To save memory when using very long sequences, you can set the
               length of the sequence to the length of the sequence (and nothing
               else):
               my $seqobj = Bio::PrimarySeq->new( -seq => 'ACGT...' ); # 1 Mbp sequence
@@ -477,8 +496,7 @@ sub length {
     if (defined $val) {
         my $len = $self->{'length'};
         if ($len && ($len != $val)) {
-            $self->throw("You're trying to lie about the length: ".
-                "is $len but you say ".$val);
+            $self->throw("Can not set the length to $val, current length value is $len");
         }
         $self->{'length'} = $val;
         $self->{'_freeze_length'} = undef;
