@@ -1,6 +1,7 @@
 package Bio::Root::Test;
 use strict;
 use warnings;
+
 # According to Ovid, 'use base' can override signal handling, so use
 # old-fashioned way. This should be a Test::Builder::Module subclass
 # for consistency (as are any Test modules)
@@ -12,13 +13,6 @@ use File::Spec;
 
 our @ISA = qw(Test::Builder::Module);
 
-# ABSTRACT: a common base for all Bioperl test scripts
-# AUTHOR:   Sendu Bala <bix@sendu.me.uk>
-# OWNER:    Sendu Bala
-# LICENSE:  Perl_5
-
-# CONTRIBUTOR: Chris Fields <cjfields@bioperl.org>
-
 =head1 SYNOPSIS
 
   use lib '.'; # (for core package tests only)
@@ -81,6 +75,10 @@ test_debug().
 Finally, it presents a consistent way of getting the path to input and output
 files. See test_input_file(), test_output_file() and test_output_dir().
 
+=head1 AUTHOR Sendu Bala
+
+Chris Fields
+
 =cut
 
 # TODO: Evil magic ahead; can we clean this up?
@@ -89,47 +87,55 @@ files. See test_input_file(), test_output_file() and test_output_dir().
     my $Tester = Test::Builder->new;
 
     no warnings 'redefine';
+
     sub Test::Warn::_canonical_got_warning {
-        my ($called_from, $msg) = @_;
-        my $warn_kind = $called_from eq 'Carp' ? 'carped' : ($called_from =~ /Bio::/ ? 'Bioperl' : 'warn');
+        my ( $called_from, $msg ) = @_;
+        my $warn_kind
+            = $called_from eq 'Carp'
+            ? 'carped'
+            : ( $called_from =~ /Bio::/ ? 'Bioperl' : 'warn' );
 
         my $warning;
-        if ($warn_kind eq 'Bioperl') {
-            ($warning) = $msg =~ /\n--------------------- WARNING ---------------------\nMSG: (.+)\n---------------------------------------------------\n$/m;
-            $warning ||= $msg; # shouldn't ever happen
-        }
-        else {
-            my @warning_stack = split /\n/, $msg;   # some stuff of uplevel is included
+        if ( $warn_kind eq 'Bioperl' ) {
+            ($warning)
+                = $msg
+                =~ /\n--------------------- WARNING ---------------------\nMSG: (.+)\n---------------------------------------------------\n$/m;
+            $warning ||= $msg;    # shouldn't ever happen
+        } else {
+            my @warning_stack = split /\n/, $msg; # some stuff of uplevel is included
             $warning = $warning_stack[0];
         }
 
-        return {$warn_kind => $warning}; # return only the real message
+        return { $warn_kind => $warning };    # return only the real message
     }
 
     sub Test::Warn::_diag_found_warning {
         my @warns = @_;
         foreach my $warn (@warns) {
-            if (ref($warn) eq 'HASH') {
-                   ${$warn}{carped}  ? $Tester->diag("found carped warning: ${$warn}{carped}")
-                : (${$warn}{Bioperl} ? $Tester->diag("found Bioperl warning: ${$warn}{Bioperl}")
-                : $Tester->diag("found warning: ${$warn}{warn}"));
+            if ( ref($warn) eq 'HASH' ) {
+                ${$warn}{carped}
+                    ? $Tester->diag("found carped warning: ${$warn}{carped}")
+                    : (
+                    ${$warn}{Bioperl} ? $Tester->diag(
+                        "found Bioperl warning: ${$warn}{Bioperl}")
+                    : $Tester->diag("found warning: ${$warn}{warn}")
+                    );
             } else {
-                $Tester->diag( "found warning: $warn" );
+                $Tester->diag("found warning: $warn");
             }
         }
-        $Tester->diag( "didn't find a warning" ) unless @warns;
+        $Tester->diag("didn't find a warning") unless @warns;
     }
 
     sub Test::Warn::_cmp_got_to_exp_warning {
-        my ($got_kind, $got_msg) = %{ shift() };
-        my ($exp_kind, $exp_msg) = %{ shift() };
-        return 0 if ($got_kind eq 'warn') && ($exp_kind eq 'carped');
+        my ( $got_kind, $got_msg ) = %{ shift() };
+        my ( $exp_kind, $exp_msg ) = %{ shift() };
+        return 0 if ( $got_kind eq 'warn' ) && ( $exp_kind eq 'carped' );
 
         my $cmp;
-        if ($got_kind eq 'Bioperl') {
+        if ( $got_kind eq 'Bioperl' ) {
             $cmp = $got_msg =~ /^\Q$exp_msg\E$/;
-        }
-        else {
+        } else {
             $cmp = $got_msg =~ /^\Q$exp_msg\E at \S+ line \d+\.?$/;
         }
 
@@ -137,22 +143,25 @@ files. See test_input_file(), test_output_file() and test_output_dir().
     }
 }
 
-our @EXPORT = (@Test::Most::EXPORT,
-               #@Bio::Root::Test::Warn::EXPORT,
-               # Test::Warn method wrappers
+our @EXPORT = (
+    @Test::Most::EXPORT,
 
-               # BioPerl-specific
-               qw(
-                test_begin
-                test_skip
-                test_output_file
-                test_output_dir
-                test_input_file
-                test_network
-                test_email
-                test_debug
-                float_is
-             ));
+    #@Bio::Root::Test::Warn::EXPORT,
+    # Test::Warn method wrappers
+
+    # BioPerl-specific
+    qw(
+        test_begin
+        test_skip
+        test_output_file
+        test_output_dir
+        test_input_file
+        test_network
+        test_email
+        test_debug
+        float_is
+        )
+);
 
 our $GLOBAL_FRAMEWORK = 'Test::Most';
 our @TEMP_FILES;
@@ -193,25 +202,26 @@ our @TEMP_FILES;
 =cut
 
 sub test_begin {
-    my ($skip_all, $tests, $framework) = _skip(@_);
+    my ( $skip_all, $tests, $framework ) = _skip(@_);
     $GLOBAL_FRAMEWORK = $framework;
 
-    if ($framework eq 'Test::Most') {
-        # ideally we'd delay loading Test::Most until this point, but see BEGIN
-        # block
+    if ( $framework eq 'Test::Most' ) {
+
+       # ideally we'd delay loading Test::Most until this point, but see BEGIN
+       # block
 
         if ($skip_all) {
             eval "plan skip_all => '$skip_all';";
-        }
-        elsif (defined $tests && $tests == 0) {
-            eval "plan skip_all => 'These modules are now probably deprecated';";
-        }
-        elsif ($tests) {
+        } elsif ( defined $tests && $tests == 0 ) {
+            eval
+                "plan skip_all => 'These modules are now probably deprecated';";
+        } elsif ($tests) {
             eval "plan tests => $tests;";
         }
 
         return 1;
     }
+
     # go ahead and add support for other frameworks here
     else {
         die "Only Test::Most is supported at the current time\n";
@@ -261,14 +271,15 @@ sub test_begin {
 =cut
 
 sub test_skip {
-    my ($skip, $tests, $framework) = _skip(@_);
+    my ( $skip, $tests, $framework ) = _skip(@_);
     $tests || die "-tests must be a number greater than 0";
 
-    if ($framework eq 'Test::Most') {
+    if ( $framework eq 'Test::Most' ) {
         if ($skip) {
             eval "skip('$skip', $tests);";
         }
     }
+
     # go ahead and add support for other frameworks here
     else {
         die "Only Test::Most is supported at the current time\n";
@@ -291,8 +302,8 @@ sub test_output_file {
 
     # RT 48813
     my $tmp = File::Temp->new();
-    push(@TEMP_FILES, $tmp);
-    close($tmp); # Windows needs this
+    push( @TEMP_FILES, $tmp );
+    close($tmp);    # Windows needs this
     return $tmp->filename;
 }
 
@@ -312,7 +323,7 @@ sub test_output_file {
 sub test_output_dir {
     die "test_output_dir takes no args\n" if @_;
 
-    return tempdir(CLEANUP => 1);
+    return tempdir( CLEANUP => 1 );
 }
 
 =head2 test_input_file
@@ -330,7 +341,7 @@ sub test_output_dir {
 =cut
 
 sub test_input_file {
-    return File::Spec->catfile('t', 'data', @_);
+    return File::Spec->catfile( 't', 'data', @_ );
 }
 
 =head2 test_network
@@ -344,7 +355,12 @@ sub test_input_file {
 =cut
 
 sub test_network {
-    return $ENV{AUTHOR_TESTING} || $ENV{RELEASE_TESTING};
+    require Module::Build;
+    my $build = Module::Build->current();
+    return
+           $build->notes('network')
+        || $ENV{AUTHOR_TESTING}
+        || $ENV{RELEASE_TESTING};
 }
 
 =head2 test_email
@@ -358,7 +374,14 @@ sub test_network {
 =cut
 
 sub test_email {
-    return $ENV{AUTHOR_TESTING} || $ENV{RELEASE_TESTING};
+    require Module::Build;
+    my $build = Module::Build->current();
+
+    # this should not be settable unless the network tests work
+    return
+           $build->notes('email')
+        || $ENV{AUTHOR_TESTING}
+        || $ENV{RELEASE_TESTING};
 }
 
 =head2 test_debug
@@ -387,12 +410,13 @@ sub test_debug {
 =cut
 
 sub float_is ($$;$) {
-    my ($val1, $val2, $message) = @_;
+    my ( $val1, $val2, $message ) = @_;
+
     # catch any potential undefined values and directly compare
-    if (!defined $val1 || !defined $val2) {
-        is($val1, $val2 ,$message);
+    if ( ! defined $val1 || ! defined $val2 ) {
+        is( $val1, $val2, $message );
     } else {
-        is(sprintf("%g",$val1), sprintf("%g",$val2),$message);
+        is( sprintf( "%g", $val1 ), sprintf( "%g", $val2 ), $message );
     }
 }
 
@@ -406,21 +430,23 @@ sub _skip {
 
     # handle input strictly
     my $tests = $args{'-tests'};
-    #(defined $tests && $tests =~ /^\d+$/) || die "-tests must be supplied and be an int\n";
+
+#(defined $tests && $tests =~ /^\d+$/) || die "-tests must be supplied and be an int\n";
     delete $args{'-tests'};
 
     my $req_mods = $args{'-requires_modules'};
     delete $args{'-requires_modules'};
     my @req_mods;
     if ($req_mods) {
-        ref($req_mods) eq 'ARRAY' || die "-requires_modules takes an array ref\n";
+        ref($req_mods) eq 'ARRAY'
+            || die "-requires_modules takes an array ref\n";
         @req_mods = @{$req_mods};
     }
     my $req_mod = $args{'-requires_module'};
     delete $args{'-requires_module'};
     if ($req_mod) {
         ref($req_mod) && die "-requires_module takes a string\n";
-        push(@req_mods, $req_mod);
+        push( @req_mods, $req_mod );
     }
 
     my $req_net = $args{'-requires_networking'};
@@ -438,8 +464,12 @@ sub _skip {
     my $req_exe = $args{'-requires_executable'};
     delete $args{'-requires_executable'};
 
-    if ($req_exe && (!ref($req_exe) || !$req_exe->isa('Bio::Tools::Run::WrapperBase'))) {
-        die "-requires_exe takes an argument of type Bio::Tools::Run::WrapperBase";
+    if ($req_exe
+        && (   ! ref($req_exe)
+            || ! $req_exe->isa('Bio::Tools::Run::WrapperBase') )
+        ) {
+        die
+            "-requires_exe takes an argument of type Bio::Tools::Run::WrapperBase";
     }
 
     my $os = $args{'-excludes_os'};
@@ -449,48 +479,56 @@ sub _skip {
     delete $args{'-framework'};
 
     # catch user mistakes
-    while (my ($key, $val) = each %args) {
-        die "unknown argument '$key' supplied, did you mistake 'required...' for 'requires...'?\n";
+    while ( my ( $key, $val ) = each %args ) {
+        die
+            "unknown argument '$key' supplied, did you mistake 'required...' for 'requires...'?\n";
     }
 
     # test user requirments and return
     if ($os) {
-        if ($^O =~ /$os/i) {
-            return ('Not compatible with your Operating System', $tests, $framework);
+        if ( $^O =~ /$os/i ) {
+            return ( 'Not compatible with your Operating System',
+                $tests, $framework );
         }
     }
 
     foreach my $mod (@req_mods) {
         my $skip = _check_module($mod);
         if ($skip) {
-            return ($skip, $tests, $framework);
+            return ( $skip, $tests, $framework );
         }
     }
 
-    if ($req_net && ! test_network()) {
-        return ('Network tests have not been requested', $tests, $framework);
+    if ( $req_net && ! test_network() ) {
+        return ( 'Network tests have not been requested', $tests,
+            $framework );
     }
 
-    if ($req_email && ! test_email()) {
-        return ('Valid email not provided; required for tests', $tests, $framework);
+    if ( $req_email && ! test_email() ) {
+        return ( 'Valid email not provided; required for tests',
+            $tests, $framework );
     }
 
     if ($req_exe) {
-        my $eval = eval {$req_exe->executable};
-        if ($@ or not defined $eval) {
-            my $msg = 'Required executable for '.ref($req_exe).' is not present';
+        my $eval = eval { $req_exe->executable };
+        if ( $@ or not defined $eval ) {
+            my $msg
+                = 'Required executable for '
+                . ref($req_exe)
+                . ' is not present';
             diag($msg);
-            return ($msg, $tests, $framework);
+            return ( $msg, $tests, $framework );
         }
     }
 
-    if ($req_env && !exists $ENV{$req_env}) {
-        my $msg = 'Required environment variable $'.$req_env. ' is not set';
+    if ( $req_env && ! exists $ENV{$req_env} ) {
+        my $msg
+            = 'Required environment variable $' . $req_env . ' is not set';
         diag($msg);
-        return ($msg, $tests, $framework);
+        return ( $msg, $tests, $framework );
     }
 
-    return ('', $tests, $framework);
+    return ( '', $tests, $framework );
 }
 
 =head2 _check_module
@@ -501,28 +539,29 @@ sub _check_module {
     my $mod = shift;
 
     my $desired_version;
-    if ($mod =~ /(\S+)\s+(\S+)/) {
-        $mod = $1;
+    if ( $mod =~ /(\S+)\s+(\S+)/ ) {
+        $mod             = $1;
         $desired_version = $2;
     }
 
     eval "require $mod;";
 
     if ($@) {
-        if ($@ =~ /Can't locate/) {
-            return "The optional module $mod (or dependencies thereof) was not installed";
+        if ( $@ =~ /Can't locate/ ) {
+            return
+                "The optional module $mod (or dependencies thereof) was not installed";
+        } else {
+            return
+                "The optional module $mod generated the following error: \n$@";
         }
-        else {
-            return "The optional module $mod generated the following error: \n$@";
-        }
-    }
-    elsif ($desired_version) {
+    } elsif ($desired_version) {
         no strict 'refs';
-        unless (defined ${"${mod}::VERSION"}) {
-            return "The optional module $mod didn't have a version, but we want v$desired_version";
-        }
-        elsif (${"${mod}::VERSION"} < $desired_version) {
-            return "The optional module $mod was out of date (wanted v$desired_version)";
+        unless ( defined ${"${mod}::VERSION"} ) {
+            return
+                "The optional module $mod didn't have a version, but we want v$desired_version";
+        } elsif ( ${"${mod}::VERSION"} < $desired_version ) {
+            return
+                "The optional module $mod was out of date (wanted v$desired_version)";
         }
     }
 
