@@ -1043,15 +1043,16 @@ This includes methods for retrieving, adding, and removing features.
            feature object in order to traverse all features associated
            with this sequence.
 
-           Top-level features can be obtained by tag, specified in 
+           Specific features can be obtained by primary tag, specified in 
            the argument.
 
            Use get_all_SeqFeatures() if you want the feature tree
            flattened into one single array.
 
- Example :
+ Example : my @feats = $seq->get_SeqFeatures or
+           my @genefeats = $seq->get_SeqFeatures('gene')
  Returns : an array of Bio::SeqFeatureI implementing objects
- Args    : [optional] scalar string (feature tag)
+ Args    : [optional] string (feature tag)
 
 =cut
 
@@ -1163,25 +1164,31 @@ sub add_SeqFeature {
 
  Title   : remove_SeqFeatures
  Usage   : $seq->remove_SeqFeatures();
- Function: Flushes all attached SeqFeatureI objects.
-
-           To remove individual feature objects, delete those from the returned
-           array and re-add the rest.
- Example :
- Returns : The array of Bio::SeqFeatureI objects removed from this seq.
- Args    : None
+ Function: Removes all attached SeqFeatureI objects or those with the 
+           specified primary tag
+ Example : my @gene_feats = $seq->remove_seqFeatures('gene') or
+           my @feats = $seq->remove_seqFeatures()
+ Returns : The array of Bio::SeqFeatureI objects removed from the sequence
+ Args    : None, or a feature primary tag
 
 =cut
 
 sub remove_SeqFeatures {
-    my $self = shift;
-
+    my ( $self, $tag ) = @_;
     return () unless $self->{'_as_feat'};
-    my @feats = @{$self->{'_as_feat'}};
-    $self->{'_as_feat'} = [];
-    return @feats;
-}
 
+    if ( $tag ) {
+        my @selected_feats   = grep { $_->primary_tag eq $tag } @{ $self->{'_as_feat'} };
+        my @unselected_feats = grep { $_->primary_tag ne $tag } @{ $self->{'_as_feat'} };
+        $self->{'_as_feat'} = \@unselected_feats;
+        return @selected_feats;
+    }
+    else {
+        my @all_feats = @{ $self->{'_as_feat'} };
+        $self->{'_as_feat'} = [];
+        return @all_feats;
+    }
+}
 
 =head1 Methods provided in the Bio::PrimarySeqI interface
 
@@ -1191,8 +1198,8 @@ or other information as expected. See L<Bio::PrimarySeq>
 for more information.
 
 Sequence Features are B<not> transferred to the new objects.
-This is possibly a mistake. Anyone who feels the urge in
-dealing with this is welcome to give it a go.
+To reverse complement and include the features use
+L<Bio::SeqUtils::revcom_with_features>.
 
 =head2 revcom
 
