@@ -22,8 +22,6 @@ Bio::SeqFeature::PositionProxy - handle features when truncation/revcom sequence
 
    $seq->add_SeqFeature($feat);
 
-
-
 =head1 DESCRIPTION
 
 PositionProxy is a Proxy Sequence Feature to handle truncation
@@ -59,7 +57,7 @@ Report bugs to the Bioperl bug tracking system to help us keep track
 the bugs and their resolution.  Bug reports can be submitted via the
 web:
 
-  https://redmine.open-bio.org/projects/bioperl/
+  https://github.com/bioperl/bioperl-live/issues
 
 =head1 AUTHOR - Ewan Birney
 
@@ -123,11 +121,10 @@ sub new {
  Title   : location
  Usage   : my $location = $seqfeature->location()
  Function: returns a location object suitable for identifying location 
-	   of feature on sequence or parent feature  
+           of feature on sequence or parent feature  
  Returns : Bio::LocationI object
  Args    : none
 
-
 =cut
 
 sub location {
@@ -135,8 +132,8 @@ sub location {
 
     if (defined($value)) {
         unless (ref($value) and $value->isa('Bio::LocationI')) {
-	    $self->throw("object $value pretends to be a location but ".
-			 "does not implement Bio::LocationI");
+            $self->throw("object $value pretends to be a location but ".
+                "does not implement Bio::LocationI");
         }
         $self->{'_location'} = $value;
     }
@@ -156,7 +153,6 @@ sub location {
  Returns : Bio::SeqFeatureI object
  Args    : none
 
-
 =cut
 
 sub parent {
@@ -164,8 +160,8 @@ sub parent {
 
     if (defined($value)) {
         unless (ref($value) and $value->isa('Bio::SeqFeatureI')) {
-	    $self->throw("object $value pretends to be a location but ".
-			 "does not implement Bio::SeqFeatureI");
+            $self->throw("object $value pretends to be a location but ".
+                "does not implement Bio::SeqFeatureI");
         }
         $self->{'_parent'} = $value;
     }
@@ -184,7 +180,6 @@ sub parent {
  Returns : integer
  Args    : none
 
-
 =cut
 
 sub start {
@@ -192,6 +187,7 @@ sub start {
    return $self->location->start($value);
 }
 
+
 =head2 end
 
  Title   : end
@@ -201,7 +197,6 @@ sub start {
  Returns : integer
  Args    : none
 
-
 =cut
 
 sub end {
@@ -209,6 +204,7 @@ sub end {
    return $self->location->end($value);
 }
 
+
 =head2 length
 
  Title   : length
@@ -218,7 +214,6 @@ sub end {
  Returns :
  Args    :
 
-
 =cut
 
 sub length {
@@ -226,6 +221,7 @@ sub length {
    return $self->end - $self->start() + 1;
 }
 
+
 =head2 strand
 
  Title   : strand
@@ -235,7 +231,6 @@ sub length {
  Returns : -1,1 or 0
  Args    : none
 
-
 =cut
 
 sub strand {
@@ -255,7 +250,6 @@ sub strand {
  Returns : TRUE on success
  Args    :
 
-
 =cut
 
 sub attach_seq {
@@ -271,12 +265,13 @@ sub attach_seq {
 
    foreach my $sf ( $self->sub_SeqFeature() ) {
        if ( $sf->can("attach_seq") ) {
-	   $sf->attach_seq($seq);
+           $sf->attach_seq($seq);
        }
    }
    return 1;
 }
 
+
 =head2 seq
 
  Title   : seq
@@ -286,7 +281,6 @@ sub attach_seq {
  Returns : sub seq on attached sequence bounded by start & end
  Args    : none
 
-
 =cut
 
 sub seq {
@@ -313,6 +307,7 @@ sub seq {
    return $seq;
 }
 
+
 =head2 entire_seq
 
  Title   : entire_seq
@@ -322,7 +317,6 @@ sub seq {
  Returns :
  Args    :
 
-
 =cut
 
 sub entire_seq {
@@ -348,24 +342,21 @@ sub entire_seq {
  Returns : value of seqname
  Args    : newvalue (optional)
 
-
 =cut
 
 sub seqname {
     my ($obj,$value) = @_;
     if ( defined $value ) {
-	$obj->{'_gsf_seqname'} = $value;
+        $obj->{'_gsf_seqname'} = $value;
     }
     return $obj->{'_gsf_seqname'};
 }
 
 
-
 =head2 Proxies
 
 These functions chain back to the parent for all non sequence related stuff.
 
-
 =cut
 
 =head2 primary_tag
@@ -377,15 +368,15 @@ These functions chain back to the parent for all non sequence related stuff.
  Returns : a string 
  Args    : none
 
-
 =cut
 
-sub primary_tag{
+sub primary_tag {
    my ($self,@args) = @_;
 
    return $self->parent->primary_tag();
 }
 
+
 =head2 source_tag
 
  Title   : source_tag
@@ -395,10 +386,9 @@ sub primary_tag{
  Returns : a string 
  Args    : none
 
-
 =cut
 
-sub source_tag{
+sub source_tag {
    my ($self) = @_;
 
    return $self->parent->source_tag();
@@ -413,44 +403,47 @@ sub source_tag{
  Returns : TRUE if the specified tag exists, and FALSE otherwise
  Args    :
 
-
 =cut
 
-sub has_tag{
+sub has_tag {
    my ($self,$tag) = @_;
 
    return $self->parent->has_tag($tag);
 }
 
-=head2 each_tag_value
 
- Title   : each_tag_value
- Usage   : @values = $self->each_tag_value('some_tag')
+=head2 get_tag_values
+
+ Title   : get_tag_values
+ Usage   : @values = $self->get_tag_values('some_tag')
  Function: 
  Returns : An array comprising the values of the specified tag.
  Args    :
 
-
 =cut
 
-sub each_tag_value {
+*each_tag_value = \&get_tag_values;
+
+sub get_tag_values {
    my ($self,$tag) = @_;
 
-   return $self->parent->each_tag_value($tag);
+   return $self->parent->get_tag_values($tag);
 }
 
-=head2 all_tags
 
- Title   : all_tags
- Usage   : @tags = $feat->all_tags()
+=head2 get_all_tags
+
+ Title   : get_all_tags
+ Usage   : @tags = $feat->get_all_tags()
  Function: gives all tags for this feature
  Returns : an array of strings
  Args    : none
 
-
 =cut
 
-sub all_tags{
+*all_tags = \&get_all_tags;
+
+sub get_all_tags {
    my ($self) = @_;
 
    return $self->parent->all_tags();
