@@ -1,7 +1,8 @@
-# $Id: StructureI.pm 10525 2006-09-26 22:03:22Z sendu $
 #
 # BioPerl module for Bio::Structure::StructureI
 #
+# Please direct questions and support issues to <bioperl-l@bioperl.org>
+#
 # Cared for by Kris Boulez <kris.boulez@algonomics.com>
 #
 # Copyright Kris Boulez
@@ -33,13 +34,24 @@ the Bioperl mailing list.  Your participation is much appreciated.
   bioperl-l@bioperl.org                  - General discussion
   http://bioperl.org/wiki/Mailing_lists  - About the mailing lists
 
+=head2 Support
+
+Please direct usage questions or support issues to the mailing list:
+
+I<bioperl-l@bioperl.org>
+
+rather than to the module maintainer directly. Many experienced and
+reponsive experts will be able look at the problem and quickly
+address it. Please include a thorough description of the problem
+with code and data examples if at all possible.
+
 =head2 Reporting Bugs
 
 Report bugs to the Bioperl bug tracking system to help us keep track
 of the bugs and their resolution. Bug reports can be submitted via
 the web:
 
-  http://bugzilla.open-bio.org/
+  https://github.com/bioperl/bioperl-live/issues
 
 =head1 AUTHOR - Kris Boulez
 
