@@ -1,4 +1,4 @@
-#!/usr/bin/perl
+#!/usr/bin/env perl
 
 # This shows how the examples work when Error.pm isn't installed.
 # It also shows how to supress using Error.pm if it is installed
@@ -15,6 +15,7 @@
 BEGIN { $DONT_USE_ERROR = 1; }
 
 use strict;
+use lib qw(lib/ ../../);
 use TestObject;
 use Getopt::Long;
 
